/// <reference types="node" />
import { IDType } from "nowjs-core/lib/data";
import { IProvider } from "nowjs-core/lib/core";
import { TlsOptions } from "tls";
export interface IEmailClientTransportOptions {
    Service?: string;
    Host: string;
    Port: number;
    Username?: string;
    Password?: string;
    IsSecured?: boolean;
    RequireTLS?: boolean;
    IgnoreTLS?: boolean;
    AuthType?: string;
    AuthToken?: string;
    ConnectionTimeout?: number;
    GreetingTimeout?: number;
    SocketTimeout?: number;
    ConnectionPool?: boolean;
    ConnectionMax?: number;
    ConnectionMaxMessage?: number;
    ConnectionProxy?: string;
    TLS?: TlsOptions;
}
export interface IEmailAttachmentType {
    FileName?: string;
    Raw?: string;
    ContentID?: string;
    FilePath?: string;
    Content?: string | Buffer | NodeJS.ReadableStream;
    ContentType?: string;
    Encoding?: string;
}
export interface IEmailMessage {
    Subject: string;
    From: string;
    Sender?: string;
    To: string | string[];
    Cc?: string | string[];
    Bcc?: string | string[];
    Text?: string;
    Html?: string | Buffer | NodeJS.ReadableStream | IEmailAttachmentType;
    Attachments?: IEmailAttachmentType[];
    Refrences?: string[];
    Headers?: any;
    ReplyTo?: string;
    InReplyTo?: string;
    MessageID?: string;
    Date?: Date;
}
export interface IEmailMessageStatus {
    MessageID: number | string;
    Response: string;
    Accepted: string[];
    Rejected: string[];
    Pending: string[];
}
export interface IEmailClientOptions {
    Transport?: IEmailClientTransportOptions;
}
export interface IEmailClientProvider<TMessage extends IEmailMessage, TMessageStatus extends IEmailMessageStatus> extends IProvider {
    send(tenantID: IDType, message: TMessage, options?: IEmailClientOptions): Promise<TMessageStatus>;
}
