import { IProvider } from "nowjs-core/lib/core";
import { IDType } from "nowjs-core/lib/data";
export declare enum SmsClientSendMethod {
    OneToOne = 1,
    OneToMany = 2,
    ManyToMany = 3,
    SendTextLookup = 4,
    SendVoiceLookup = 5,
}
export declare enum SmsInqueryStatus {
    Queued = 1,
    Schechuled = 2,
    SendToGateway = 4,
    Failed = 6,
    Delivered = 10,
    Undelivered = 11,
    UserCanceled = 13,
    ReceptorBlocked = 14,
    MessageIDNotValid = 100,
    InqueryFailed = 110,
}
export declare type SmsMessageID = string;
export interface ISmsMessage {
    BatchID?: number;
    InternalID?: SmsMessageID | SmsMessageID[];
    Method: SmsClientSendMethod;
    Sender?: string | string[];
    Receptor: string | string[];
    Text?: string | string[];
    SendAt?: Date;
    TemplateName?: string;
    Params?: any;
}
export interface ISmsMessageStatus {
    MessageID: SmsMessageID;
    InternalID?: SmsMessageID;
    Text?: string;
    Status: SmsInqueryStatus;
    StatusMessage?: string;
    Sender?: string;
    Receptor?: string;
    SentOn?: Date;
    CostAmount?: number;
    CurrencyType?: string;
}
export interface ISmsClientAccountInfo {
    CreditAmount?: number;
    CurrencyType?: string;
    ExpiresAt?: Date;
    Type?: string;
}
export interface ISmsClientAccountOptions {
    Address?: string;
    Token?: string;
    Username?: string;
    Password?: string;
}
export interface ISmsClientOptions {
    ProviderName?: string;
    Account?: ISmsClientAccountOptions;
}
export interface ISmsClientProvider<TMessage extends ISmsMessage, TMessageStatus extends ISmsMessageStatus> extends IProvider {
    send(tenantID: IDType, message: TMessage, options?: ISmsClientOptions): Promise<TMessageStatus[]>;
    inquery(tenantID: IDType, messageid: SmsMessageID, options?: ISmsClientOptions): Promise<TMessageStatus[]>;
    inqueryByInternalID(tenantID: IDType, internalid: SmsMessageID, options?: ISmsClientOptions): Promise<TMessageStatus[]>;
    accountInfo(tenantID: IDType, options?: ISmsClientOptions): Promise<ISmsClientAccountInfo>;
}
